vmshepherd.http package
=======================

Submodules
----------

vmshepherd.http.rpc\_api module
-------------------------------

.. automodule:: vmshepherd.http.rpc_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vmshepherd.http
    :members:
    :undoc-members:
    :show-inheritance:
